@@ -10,17 +10,22 @@ from .editing import (
     INDENT_SIZE,
     MutationType,
     WrappingSummary,
-    apply_insertions,
     merge_insertions,
     indent_interim_lines,
 )
 from .wrappers import WRAPPING_FUNTIONS
+from .exceptions import TuckError
 
 TAst = TypeVar('TAst', bound=ast.AST)
 
 WRAPPABLE_NODE_TYPES = tuple(x for x, _ in WRAPPING_FUNTIONS)
 
 
+class TargetSyntaxError(TuckError):
+    def __init__(self, inner: SyntaxError) -> None:
+        super().__init__('target_syntax_error', str(inner))
+
+
 def get_wrapping_summary(asttokens: ASTTokens, node: ast.AST) -> WrappingSummary:
     for ast_type, func in WRAPPING_FUNTIONS:
         if isinstance(node, ast_type):
@@ -32,7 +37,7 @@ def get_wrapping_summary(asttokens: ASTTokens, node: ast.AST) -> WrappingSummary
     raise AssertionError("Unsupported node type {}".format(node))
 
 
-def optimise_wrapping_summary(
+def remove_redunant_wrapping_operations(
     asttokens: ASTTokens,
     wrapping_summary: WrappingSummary,
 ) -> WrappingSummary:
@@ -109,7 +114,7 @@ def determine_insertions(asttokens: ASTTokens, position: Position) -> List[Inser
 
     wrapping_summary = indent_interim_lines(asttokens, wrapping_summary)
 
-    wrapping_summary = optimise_wrapping_summary(asttokens, wrapping_summary)
+    wrapping_summary = remove_redunant_wrapping_operations(asttokens, wrapping_summary)
 
     insertions = [
         (pos, ''.join(mutations[x] for x in mutation_types))
@@ -123,14 +128,17 @@ def process(
     positions: List[Position],
     content: str,
     filename: str,
-) -> Tuple[str, List[Insertion]]:
-    asttokens = ASTTokens(content, parse=True, filename=filename)
+) -> List[Insertion]:
+    try:
+        asttokens = ASTTokens(content, parse=True, filename=filename)
+    except SyntaxError as e:
+        # Catch syntax errors within the file we were asked to parse. We trust
+        # that the error is not within asttokens itself.
+        raise TargetSyntaxError(e) from e
 
     insertions = merge_insertions(
         determine_insertions(asttokens, position)
         for position in positions
     )
 
-    new_content = apply_insertions(content, insertions)
-
-    return new_content, insertions
+    return insertions
